#version 120

#define PI 3.141592653589793238462643383279

varying vec4 swVertex;
uniform sampler2D tex;
uniform float swVertexCenterX;
uniform float swVertexCenterY;
uniform float swRadiusMin;
uniform float swRadiusMax;
uniform float swEdgeSize;
uniform float swEdgeAlpha;

vec2 offset[8];

void main(){

	vec2 coord = gl_TexCoord[0].st;
	vec4 texColor = texture2D(tex, coord);
	
	vec2 center = vec2(swVertexCenterX, swVertexCenterY);
	float distanceFromCenter = distance(center, swVertex.xy);

	float insideAlpha = step(swRadiusMin, distanceFromCenter); // IF dist >= swRadiusMin --> 1.0
	float insideEdgeAlpha = (1.0 - insideAlpha) * step(swRadiusMin - swEdgeSize, distanceFromCenter);
	float glowPower = insideEdgeAlpha * sin(abs(distanceFromCenter - swRadiusMin) / swEdgeSize * PI);
	
	float outsideAlpha = step(distanceFromCenter, swRadiusMax); // IF swRadiusMax >= dist --> 1.0
	float outsideEdgeAlpha = (1.0 - outsideAlpha) * step(distanceFromCenter, swRadiusMax + swEdgeSize);
	glowPower += outsideEdgeAlpha * sin(abs(distanceFromCenter - swRadiusMax) / swEdgeSize * PI);
	
	glowPower = min(glowPower, 1.0);
	float fadeAlpha = min(insideAlpha * outsideAlpha, 1.0);
	
	vec3 texC = texColor.rgb;
	float texA = texColor.a * fadeAlpha;
	
	vec4 fadedColor = vec4(texC * gl_Color.rgb, texA);
	vec4 glowColor = vec4(pow(0.3 * glowPower, 0.5) + fadedColor.r, pow(0.3 * glowPower, 0.5) + fadedColor.g, 1.0 * glowPower + fadedColor.b, swEdgeAlpha);
	vec4 finalColor = mix(fadedColor, glowColor, glowPower * swEdgeAlpha);
	
	
	gl_FragColor = finalColor;
}
