#version 120

#define PI 3.141592653589793238462643383279

varying vec4 swVertex;
uniform float swVertexCenterX;
uniform float swVertexCenterY;
uniform float swRadiusMin;
uniform float swRadiusMax;
uniform float swRadiusWidth;
uniform float swRed;
uniform float swGreen;
uniform float swBlue;
uniform float swClipAngleMin;
uniform float swClipAngleMax;
uniform float swAdjustAngle;
uniform float swBaseAlpha;
uniform float swMaxAlpha;

void main() {
	
	vec2 center = vec2(swVertexCenterX, swVertexCenterY);
	
	float distance = distance(center, swVertex.xy);
	
	float angle = atan(-(swVertex.y - center.y), swVertex.x - center.x);
	float altAngle = angle + 2.0 * PI;
	
	if (distance >= swRadiusMin && distance <= swRadiusMax && 
		((angle >= swClipAngleMin && angle <= swClipAngleMax) ||
		(altAngle >= swClipAngleMin && altAngle <= swClipAngleMax))
		) {
		float gradient = sin((distance - swRadiusMin) / swRadiusWidth * PI);
		gradient = (gradient * (1.0 - (1.0 / swRadiusWidth))) + (0.7 / swRadiusWidth); // lose interference (high-quality)
		float value = 0.1 + (gradient * 0.65);
		float alpha = gradient * swMaxAlpha + swBaseAlpha;
		gl_FragColor = vec4(swRed * value, swGreen * value, swBlue * value, alpha);
	} else {
		gl_FragColor = vec4(0.0, 0.0, 0.0, 0.0);
	}
	
}
