#version 120

#define PI  3.1415926535897932384626433832795
#define TWOPI 6.283185307179586476925286766559

varying vec4 swVertex;
uniform float swLineWidth;
uniform float swOriginX;
uniform float swOriginY;
uniform float swDestX;
uniform float swDestY;
uniform float swProgressMin;
uniform float swProgressMax;
uniform float swGlowMin;
uniform float swGlowWidth;
uniform float swFadeinMin;
uniform float swFadeinMax;

float distToLine(vec2 pt1, vec2 pt2, vec2 testPt)
{
  vec2 lineDir = pt2 - pt1;
  vec2 perpDir = vec2(lineDir.y, -lineDir.x);
  vec2 dirToPt1 = pt1 - testPt;
  return abs(dot(normalize(perpDir), dirToPt1));
}

void main() {

	vec2 originPoint = vec2(swOriginX, swOriginY);
	vec2 destPoint = vec2(swDestX, swDestY);
	
	float distanceOffDiagonal = distToLine(originPoint, destPoint, swVertex.xy);
	float distanceFromOrigin = distance(originPoint, swVertex.xy) / distance(originPoint, destPoint);
	
	if (distanceOffDiagonal <= swLineWidth / 2.0) {
		float gradient = cos(distanceOffDiagonal / swLineWidth * PI);
		
		float glowGradient = sin(clamp(distanceFromOrigin - swGlowMin, 0.0, swGlowWidth) / swGlowWidth * PI);
		float progress = step(swProgressMin, distanceFromOrigin) * step(distanceFromOrigin, swProgressMax);
		float fadeinAlpha = step(swFadeinMin, distanceFromOrigin) * step(distanceFromOrigin, swFadeinMax);
						 
		float red = 0.1 + (gradient * 0.65);
		float green = red * progress;
		red *= (1.0 - progress);
		float yellow = gradient * glowGradient * 0.95;
		float alpha = gradient * 0.75 * fadeinAlpha;
		gl_FragColor = vec4(mix(yellow, 1.0, red), mix(yellow, 1.0, green), 0.0, alpha);
	} else {
		gl_FragColor = vec4(0.0, 0.0, 0.0, 0.0);
	}
	
}
