#version 120

#define PI  3.1415926535897932384626433832795
#define TWOPI 6.283185307179586476925286766559

varying vec4 swVertex;
uniform float swVertexCenterX;
uniform float swVertexCenterY;
uniform float swSpiralWidth;
uniform float swSpiralYMultiplier;
uniform float swSpiralAdjustAngle;
uniform float swSpiralAngleOffset;
uniform float swSpiralIncline;
uniform float swSpiralClipInner;
uniform float swSpiralClipOuter;
uniform float swSpiralClipAngleMin;
uniform float swSpiralClipAngleMax;
uniform float swSpiralGlowDistanceMin;
uniform float swSpiralGlowWidth;
uniform float swSpiralProgressDistanceMin;
uniform float swSpiralProgressDistanceMax;
uniform float swSpiralProgressAngleMin;
uniform float swSpiralProgressAngleMax;
uniform float swSpiralFadeinDistanceMin;
uniform float swSpiralFadeinDistanceMax;
uniform float swSpiralFadeinAngleMin;
uniform float swSpiralFadeinAngleMax;

void main() {
	
	vec2 center = vec2(swVertexCenterX, swVertexCenterY);
	
	float distance = distance(center, swVertex.xy);
	
	float angle = atan(-(swVertex.y - center.y) * swSpiralYMultiplier, swVertex.x - center.x);
	float extraturns = step(PI, swSpiralClipAngleMax - angle); // IF (abs(maxAngle - angle) >= PI)
	extraturns *= swSpiralAdjustAngle; // AND (arc moves over left edge)
	extraturns *= abs(sign(angle)); // AND (angle != 0)
	angle += extraturns * TWOPI; // THEN add 2*PI
		
	float radius = swSpiralIncline * (angle + swSpiralAngleOffset);
	
	float adjustedWidth = swSpiralWidth + (swSpiralIncline / distance * 3.0);
	float adjustedWidthHalf = adjustedWidth / 2.0;
	
	float radiusMin = max(radius - adjustedWidthHalf, swSpiralClipInner);
	float radiusMax = min(radius + adjustedWidthHalf, swSpiralClipOuter);
	
	if (distance >= radiusMin && distance <= radiusMax && angle >= swSpiralClipAngleMin && angle <= swSpiralClipAngleMax) {
	//if (distance >= radiusMin && distance <= radiusMax) {
	//if (true) {
		float gradient = sin((distance - radiusMin) / adjustedWidth * PI);
		float glowGradient = sin(clamp(distance - swSpiralGlowDistanceMin, 0.0, swSpiralGlowWidth) / swSpiralGlowWidth * PI);
		float progress = step(swSpiralProgressDistanceMin, distance) * step(distance, swSpiralProgressDistanceMax) *
						 step(swSpiralProgressAngleMin, angle) * step(angle, swSpiralProgressAngleMax);
		float fadeinAlpha = step(swSpiralFadeinDistanceMin, distance) * step(distance, swSpiralFadeinDistanceMax) *
						 step(swSpiralFadeinAngleMin, angle) * step(angle, swSpiralFadeinAngleMax);
		float red = 0.1 + (gradient * 0.65);
		float green = red * progress;
		red *= (1.0 - progress);
		float yellow = gradient * glowGradient * 0.95;
		float alpha = gradient * 0.75 * fadeinAlpha;
		gl_FragColor = vec4(mix(yellow, 1.0, red), mix(yellow, 1.0, green), 0.0, alpha);
	} else {
		gl_FragColor = vec4(0.0, 0.0, 0.0, 0.0);
	}
	
}
